MediaButtonsDeviceRequest

Enum MediaButtonsDeviceRequest 

pub enum MediaButtonsDeviceRequest {
    SimulateButtonPress {
        payload: MediaButtonsDeviceSimulateButtonPressRequest,
        responder: MediaButtonsDeviceSimulateButtonPressResponder,
    },
    SendButtonsState {
        payload: MediaButtonsDeviceSendButtonsStateRequest,
        responder: MediaButtonsDeviceSendButtonsStateResponder,
    },
    ScheduleSimulateButtonPress {
        payload: MediaButtonsDeviceScheduleSimulateButtonPressRequest,
        responder: MediaButtonsDeviceScheduleSimulateButtonPressResponder,
    },
}
A tool to inject media button events into Input Pipeline.

Please extend as necessary.

Variants



SimulateButtonPress

Simulates a button press and release on the requested button on the device.



SendButtonsState

Send a vector of pressing button on the requested button on the device. Passing empty vector will release all pressing buttons.



ScheduleSimulateButtonPress

Schedules a button press and release of the requested button at a specific duration from now. “Now” is defined as the time when the request is processed by the device, so there is some latency.

Implementations