pub struct ContactInputReport {
pub contact_id: Option<u32>,
pub position_x: Option<i64>,
pub position_y: Option<i64>,
/* private fields */
}Fields
contact_id: Option<u32>position_x: Option<i64>position_y: Option<i64>Trait Implementations
Sourceimpl Clone for ContactInputReport
impl Clone for ContactInputReport
Sourcefn clone(&self) -> ContactInputReport
fn clone(&self) -> ContactInputReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContactInputReport
impl Debug for ContactInputReport
Sourceimpl<D> Decode<ContactInputReport, D> for ContactInputReportwhere
D: ResourceDialect,
impl<D> Decode<ContactInputReport, D> for ContactInputReportwhere
D: ResourceDialect,
Sourcefn new_empty() -> ContactInputReport
fn new_empty() -> ContactInputReport
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for ContactInputReport
impl Default for ContactInputReport
Sourcefn default() -> ContactInputReport
fn default() -> ContactInputReport
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<ContactInputReport, D> for &ContactInputReportwhere
D: ResourceDialect,
impl<D> Encode<ContactInputReport, D> for &ContactInputReportwhere
D: ResourceDialect,
Sourceimpl PartialEq for ContactInputReport
impl PartialEq for ContactInputReport
Sourcefn eq(&self, other: &ContactInputReport) -> bool
fn eq(&self, other: &ContactInputReport) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for ContactInputReport
impl StructuralPartialEq for ContactInputReport
Sourceimpl TypeMarker for ContactInputReport
impl TypeMarker for ContactInputReport
Sourcetype Owned = ContactInputReport
type Owned = ContactInputReport
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ContactInputReport
impl ValueTypeMarker for ContactInputReport
Sourcetype Borrowed<'a> = &'a ContactInputReport
type Borrowed<'a> = &'a ContactInputReport
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ContactInputReport as TypeMarker>::Owned,
) -> <ContactInputReport as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ContactInputReport as TypeMarker>::Owned, ) -> <ContactInputReport as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for ContactInputReport
impl RefUnwindSafe for ContactInputReport
impl Send for ContactInputReport
impl Sync for ContactInputReport
impl Unpin for ContactInputReport
impl UnsafeUnpin for ContactInputReport
impl UnwindSafe for ContactInputReport