pub struct KeyboardProxy { /* private fields */ }Implementations
Sourceimpl KeyboardProxy
impl KeyboardProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.ui.test.input/Keyboard.
Sourcepub fn take_event_stream(&self) -> KeyboardEventStream
pub fn take_event_stream(&self) -> KeyboardEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn simulate_us_ascii_text_entry(
&self,
payload: &KeyboardSimulateUsAsciiTextEntryRequest,
) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
pub fn simulate_us_ascii_text_entry( &self, payload: &KeyboardSimulateUsAsciiTextEntryRequest, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
Simulates input of the set of keystrokes required to type text,
as if on a US QWERTY keyboard.
US ASCII text get mapped to the corresponding key presses.
For example a gets mapped into a press and
a followup release of the key a on the US QWERTY keyboard. Also,
A gets mapped into a press of the Shift key, followed by a press
and release of a.
For convenience, the \n and \t get converted into Enter and Tab
keys respectively.
pub fn simulate_key_event( &self, payload: &KeyboardSimulateKeyEventRequest, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
Sourcepub fn simulate_key_press(
&self,
payload: &KeyboardSimulateKeyPressRequest,
) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
pub fn simulate_key_press( &self, payload: &KeyboardSimulateKeyPressRequest, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
Simulate one key press includes down and up event.