pub struct KeyboardSynchronousProxy { /* private fields */ }Implementations
Sourceimpl KeyboardSynchronousProxy
impl KeyboardSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<KeyboardEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<KeyboardEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn simulate_us_ascii_text_entry(
&self,
payload: &KeyboardSimulateUsAsciiTextEntryRequest,
___deadline: MonotonicInstant,
) -> Result<(), Error>
pub fn simulate_us_ascii_text_entry( &self, payload: &KeyboardSimulateUsAsciiTextEntryRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>
Simulates input of the set of keystrokes required to type text,
as if on a US QWERTY keyboard.
US ASCII text get mapped to the corresponding key presses.
For example a gets mapped into a press and
a followup release of the key a on the US QWERTY keyboard. Also,
A gets mapped into a press of the Shift key, followed by a press
and release of a.
For convenience, the \n and \t get converted into Enter and Tab
keys respectively.
pub fn simulate_key_event( &self, payload: &KeyboardSimulateKeyEventRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>
Sourcepub fn simulate_key_press(
&self,
payload: &KeyboardSimulateKeyPressRequest,
___deadline: MonotonicInstant,
) -> Result<(), Error>
pub fn simulate_key_press( &self, payload: &KeyboardSimulateKeyPressRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>
Simulate one key press includes down and up event.