MediaButtonsDeviceSynchronousProxy

Struct MediaButtonsDeviceSynchronousProxy 

pub struct MediaButtonsDeviceSynchronousProxy { /* private fields */ }

Implementations

Source

impl MediaButtonsDeviceSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<MediaButtonsDeviceEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn simulate_button_press( &self, payload: &MediaButtonsDeviceSimulateButtonPressRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>

Simulates a button press and release on the requested button on the device.

pub fn send_buttons_state( &self, payload: &MediaButtonsDeviceSendButtonsStateRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>

Send a vector of pressing button on the requested button on the device. Passing empty vector will release all pressing buttons.

pub fn schedule_simulate_button_press( &self, payload: &MediaButtonsDeviceScheduleSimulateButtonPressRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>

Schedules a button press and release of the requested button at a specific duration from now. “Now” is defined as the time when the request is processed by the device, so there is some latency.