MouseSimulateMouseEventRequest

Struct MouseSimulateMouseEventRequest 

pub struct MouseSimulateMouseEventRequest {
    pub pressed_buttons: Option<Vec<MouseButton>>,
    pub movement_x: Option<i64>,
    pub movement_y: Option<i64>,
    pub scroll_v_detent: Option<i64>,
    pub scroll_h_detent: Option<i64>,
    pub scroll_v_physical_pixel: Option<f64>,
    pub scroll_h_physical_pixel: Option<f64>,
    /* private fields */
}

Fields

pressed_buttons: Option<Vec<MouseButton>>

Set of buttons that are currently pressed. Must NOT contain duplicates.

movement_x: Option<i64>

Relative X positional displacement.

movement_y: Option<i64>

Relative Y positional displacement.

scroll_v_detent: Option<i64>

Relative vertical scrolling displacement by detent.

scroll_h_detent: Option<i64>

Relative horizontal scrolling displacement by detent.

scroll_v_physical_pixel: Option<f64>

Recommended vertical scrolling displacement by physical pixel, it is computed with accelerator, detent / mm to pixel ratio, etc.

scroll_h_physical_pixel: Option<f64>

Recommended horizontal scrolling displacement by physical pixel, it is computed with accelerator, detent / mm to pixel ratio, etc.