pub struct TouchScreenProxy { /* private fields */ }Implementations
Sourceimpl TouchScreenProxy
impl TouchScreenProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.ui.test.input/TouchScreen.
Sourcepub fn take_event_stream(&self) -> TouchScreenEventStream
pub fn take_event_stream(&self) -> TouchScreenEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn simulate_tap(
&self,
payload: &TouchScreenSimulateTapRequest,
) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
pub fn simulate_tap( &self, payload: &TouchScreenSimulateTapRequest, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
Simulates a tap at the requested location.
Sourcepub fn simulate_multi_tap(
&self,
payload: &TouchScreenSimulateMultiTapRequest,
) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
pub fn simulate_multi_tap( &self, payload: &TouchScreenSimulateMultiTapRequest, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
Simulates multi finger tap at the requested locations.
Sourcepub fn simulate_swipe(
&self,
payload: &TouchScreenSimulateSwipeRequest,
) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
pub fn simulate_swipe( &self, payload: &TouchScreenSimulateSwipeRequest, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
Simulates a swipe that starts at start_location and ends at end_location,
with a total number of move events equal to move_event_count.
The generated pointer event stream will be:
DOWN + CHANGE_1 + … + CHANGE_n + UP, where n == move_event_count
Events are injected with no explicit delay in between if duration not set.
Sourcepub fn simulate_multi_finger_gesture(
&self,
payload: &TouchScreenSimulateMultiFingerGestureRequest,
) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
pub fn simulate_multi_finger_gesture( &self, payload: &TouchScreenSimulateMultiFingerGestureRequest, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
Simulates a multi fingers linear gesture that starts at start_locations
and ends at end_locations, with a total number of move events equal to
move_event_count. if the arguments are invalid, the server should close
the connection.
The generated pointer event stream will be:
DOWN + CHANGE_1 + … + CHANGE_n + UP, where n == move_event_count
Events are injected with a small explicit delay in between.
pub fn simulate_touch_event( &self, report: &TouchInputReport, ) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>