pub struct TouchScreenSynchronousProxy { /* private fields */ }Implementations
Sourceimpl TouchScreenSynchronousProxy
impl TouchScreenSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<TouchScreenEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<TouchScreenEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn simulate_tap(
&self,
payload: &TouchScreenSimulateTapRequest,
___deadline: MonotonicInstant,
) -> Result<(), Error>
pub fn simulate_tap( &self, payload: &TouchScreenSimulateTapRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>
Simulates a tap at the requested location.
Sourcepub fn simulate_multi_tap(
&self,
payload: &TouchScreenSimulateMultiTapRequest,
___deadline: MonotonicInstant,
) -> Result<(), Error>
pub fn simulate_multi_tap( &self, payload: &TouchScreenSimulateMultiTapRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>
Simulates multi finger tap at the requested locations.
Sourcepub fn simulate_swipe(
&self,
payload: &TouchScreenSimulateSwipeRequest,
___deadline: MonotonicInstant,
) -> Result<(), Error>
pub fn simulate_swipe( &self, payload: &TouchScreenSimulateSwipeRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>
Simulates a swipe that starts at start_location and ends at end_location,
with a total number of move events equal to move_event_count.
The generated pointer event stream will be:
DOWN + CHANGE_1 + … + CHANGE_n + UP, where n == move_event_count
Events are injected with no explicit delay in between if duration not set.
Sourcepub fn simulate_multi_finger_gesture(
&self,
payload: &TouchScreenSimulateMultiFingerGestureRequest,
___deadline: MonotonicInstant,
) -> Result<(), Error>
pub fn simulate_multi_finger_gesture( &self, payload: &TouchScreenSimulateMultiFingerGestureRequest, ___deadline: MonotonicInstant, ) -> Result<(), Error>
Simulates a multi fingers linear gesture that starts at start_locations
and ends at end_locations, with a total number of move events equal to
move_event_count. if the arguments are invalid, the server should close
the connection.
The generated pointer event stream will be:
DOWN + CHANGE_1 + … + CHANGE_n + UP, where n == move_event_count
Events are injected with a small explicit delay in between.
pub fn simulate_touch_event( &self, report: &TouchInputReport, ___deadline: MonotonicInstant, ) -> Result<(), Error>